#include <AI8051U.H>
#include "UART2.h"

bit		S2_busy;			//串口忙标志
char	S2_wptr;			//写指针
char	S2_rptr;			//读指针
char	S2_buffer[16];		//接受缓存，长度16
char	S2_RITI;		//RI TI缓存

/**
  * @brief  串口2初始化
  * @param  无
  * @retval 无
  */
void Uart2_Init(void)			//UART2初始化
{
	P_SW2 &= 0xFE;		//RXD2：P12  TXD2：P13
	S2CFG = 0x01;		//当使用串口2时，W1必须置1
	
	S2CON = 0x50;		//模式1（8位数据）、接受使能
	AUXR |= 0x01;		//串口2选择定时器2为波特率发生器
	AUXR |= 0x04;		//定时器时钟1T模式
	TL2 = BRT;			//波特率对应的重载值
	TH2 = BRT >> 8;
	AUXR |= 0x10;		//定时器2开始计时
	IP2 &= 0xFE;		//PS2 = 0;串口1中断优先级
	//IE2 |= 0x01;		//ES2 = 1;使能串口2中断
	//EA = 1;			//使能总中断
	
	S2_wptr = 0x00;		//清零写指针
	S2_rptr = 0x00;		//清零读指针
	S2_busy = 0;		//清零忙指针
}

/**
  * @brief  串口2发送一个字符
  * @param  dat 要发送的一个字符
  * @retval 无
  */
void Uart2_Send(char dat)		//发送字符函数
{
	while (S2_busy);		//当串口忙，等待
	S2_busy = 1;			//忙标志置1
	S2BUF = dat;			//发送数据dat
}

/**
  * @brief  串口2发送一个字符串
  * @param  *p 要发送的一个字符串
  * @retval 无
  */
void Uart2_SendStr(char *p)	//发送字符串函数
{
	while (*p)			//字符串结束前‘\0’前循环
	{
		Uart2_Send(*p++);	//逐个发送字符串的字符
	}
}

/*串口中断函数模板
void Uart2_Isr(void) interrupt 8
{
	S2_RITI = S2CON;
	if (S2_RITI & 0x02)			//发送中断标志置1时
	{
		S2CON &= ~0x02;			//清零发送中断标志
		busy = 0;				//清零忙状态
	}
	if (S2_RITI & 0x01)			//接收中断标志置1时
	{
		S2CON &= ~0x01;			//清零接收中断标志
		buffer[wptr++] = S2BUF;	//接受长度16
		wptr &= 0x0f;			//接受长度16
	}
	S2_RITI = 0x00;
}
*/